(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('quill')) :
  typeof define === 'function' && define.amd ? define(['exports', 'quill'], factory) :
  (global = global || self, factory(global.quillImageUploader = {}, global.Quill));
}(this, function (exports, Quill) { 'use strict';

  Quill = Quill && Quill.hasOwnProperty('default') ? Quill['default'] : Quill;

  function defaultHandleError(error) {
    return Promise.reject(error);
  }

  var defaultInvalidFile = function defaultInvalidFile() {};

  var ImageUploadModule =
  /*#__PURE__*/
  function () {
    function ImageUploadModule(quill, options) {
      this.quill = quill;
      this.options = options;
      this.range = null;

      if (typeof this.options.upload !== 'function') {
        throw new Error('[Missing config] upload function that returns a promise is required');
      }

      if (this.options.accept && !Array.isArray(this.options.accept)) {
        throw new Error('Expect "accept" to be an array of file formats');
      }

      this.quill.getModule('toolbar').addHandler('image', this.selectLocalImage.bind(this));
    }

    var _proto = ImageUploadModule.prototype;

    _proto.selectLocalImage = function selectLocalImage() {
      var _this = this;

      this.range = this.quill.getSelection(true);
      var fileInput = document.createElement('input');
      fileInput.setAttribute('type', 'file');
      fileInput.setAttribute('accept', this.options.accept ? this.options.accept.join(',') : 'image/*');

      fileInput.onchange = function () {
        return _this.selectFile(fileInput.files[0]);
      };

      fileInput.click();
    };

    _proto.validate = function validate(file) {
      var _this$options = this.options,
          maxSize = _this$options.maxSize,
          accept = _this$options.accept;

      if (maxSize && file.size > maxSize) {
        return false;
      }

      if (accept && !accept.includes(file.type)) {
        return false;
      }

      return true;
    };

    _proto.selectFile = function selectFile(file) {
      var _this2 = this;

      if (!file) {
        return null;
      }

      var isValid = this.validate(file);

      if (!isValid) {
        var onInvalid = this.options.invalid || defaultInvalidFile;
        onInvalid(file);
        return null;
      }

      this.tryToInsertPlaceholder(file);
      return this.options.upload(file).then(function (url) {
        _this2.deleteImagePlaceholder();

        _this2.insertImage(url);
      }).catch(function (error) {
        _this2.deleteImagePlaceholder();

        var handleError = _this2.options.uploadError || defaultHandleError;
        return handleError(error);
      });
    };

    _proto.tryToInsertPlaceholder = function tryToInsertPlaceholder(file) {
      var _this3 = this;

      if (this.options.imagePlaceholder === false) {
        return;
      }

      if (this.options.imagePlaceholder) {
        this.insertImage(this.options.imagePlaceholder, 'imageUploadPlaceholder');
      } else {
        var reader = new FileReader();
        reader.addEventListener('load', function () {
          _this3.insertImage(reader.result, 'imageUploadPlaceholder');
        }, false);
        reader.readAsDataURL(file);
      }
    };

    _proto.deleteImagePlaceholder = function deleteImagePlaceholder() {
      this.quill.deleteText(this.range.index, 2);
    };

    _proto.insertImage = function insertImage(url, format) {
      if (format === void 0) {
        format = 'image';
      }

      this.quill.insertEmbed(this.range.index, format, url);
    };

    return ImageUploadModule;
  }();

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, {
        value: value,
        enumerable: true,
        configurable: true,
        writable: true
      });
    } else {
      obj[key] = value;
    }

    return obj;
  }

  function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    subClass.__proto__ = superClass;
  }

  var Image = Quill.import('formats/image');

  var ImageUploadPlaceholder =
  /*#__PURE__*/
  function (_Image) {
    _inheritsLoose(ImageUploadPlaceholder, _Image);

    function ImageUploadPlaceholder() {
      return _Image.apply(this, arguments) || this;
    }

    return ImageUploadPlaceholder;
  }(Image);

  _defineProperty(ImageUploadPlaceholder, "blotName", 'imageUploadPlaceholder');

  _defineProperty(ImageUploadPlaceholder, "className", 'image-uploading');

  Quill.register('formats/_imageUploadPlaceholder', ImageUploadPlaceholder);

  exports.ImageUploadModule = ImageUploadModule;
  exports.ImageUploadPlaceholder = ImageUploadPlaceholder;

  Object.defineProperty(exports, '__esModule', { value: true });

}));
